import isArray from "lodash/isArray";
import { createAsyncAction, errorResult, successResult } from "pullstate";

import { fetch } from "api";
import { GlobalInfoStore } from "stores";

export const loadConfig = createAsyncAction(
  async () => {
    try {
      const resp = await fetch("/config");
      const payload = await resp.json();

      if (!isArray(payload)) {
        return errorResult([], "Unexpected response format");
      }

      return successResult(payload);
    } catch (err) {
      return errorResult([], err.toString());
    }
  },
  {
    postActionHook: ({ result }) => {
      if (!result.error) {
        GlobalInfoStore.update((state) => {
          result.payload.forEach((rawConfigItem) => {
            if (rawConfigItem.id === "stream_url") {
              state.streamUrl = rawConfigItem.value;
            }
          });
        });
      }
    },
  }
);
